==> genometools-1.3.0.tar.gz: genometools-1.3.0/src/extended/region_node_builder.h <==
/*
  Copyright (c) 2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef REGION_NODE_BUILDER_H
#define REGION_NODE_BUILDER_H

#include "core/queue.h"
#include "core/range.h"

typedef struct GtRegionNodeBuilder GtRegionNodeBuilder;

GtRegionNodeBuilder* gt_region_node_builder_new(void);
void                 gt_region_node_builder_delete(GtRegionNodeBuilder*);
void                 gt_region_node_builder_add_region(GtRegionNodeBuilder*,
                                                       const char *region_name,
                                                       GtRange region_range);
void                 gt_region_node_builder_build(const GtRegionNodeBuilder*,
                                                  GtQueue *genome_nodes);
void                 gt_region_node_builder_reset(GtRegionNodeBuilder*);

#endif

==> genometools_1.5.0.orig.tar.gz: genometools-1.5.0/src/extended/region_node_builder.h <==
/*
  Copyright (c) 2008, 2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef REGION_NODE_BUILDER_H
#define REGION_NODE_BUILDER_H

#include "core/queue_api.h"
#include "core/range_api.h"

typedef struct GtRegionNodeBuilder GtRegionNodeBuilder;

GtRegionNodeBuilder* gt_region_node_builder_new(void);
void                 gt_region_node_builder_delete(GtRegionNodeBuilder*);
void                 gt_region_node_builder_add_region(GtRegionNodeBuilder*,
                                                       const char *region_name,
                                                       GtRange region_range);
void                 gt_region_node_builder_build(const GtRegionNodeBuilder*,
                                                  GtQueue *genome_nodes);
void                 gt_region_node_builder_reset(GtRegionNodeBuilder*);

#endif
